@@ -17,7 +17,7 @@ from .explorer import Explorer, ExplorerState
 from .help_layout import HelpState, random_error_quote
 from .overview import Overview, OverviewState, PreviewState
 
-version = "1.5.0"
+version = "1.5.1"
 
 # TODO object highlighted on stack view should be shown on the overview
 # TODO support ctrl-a + (whatever emacs keybinding to go to end of line)
@@ -269,8 +269,6 @@ class ObjExploreApp:
         elif key == "G":
             self.explorer.move_bottom()
 
-        # Overview ############################################################
-
         # Switch between public and private attributes
         elif key in ("[", "]"):
             if self.explorer.state == ExplorerState.public:
@@ -279,6 +277,17 @@ class ObjExploreApp:
             elif self.explorer.state == ExplorerState.private:
                 self.explorer.state = ExplorerState.public
 
+        elif key == "+":
+            self.explorer.increase_width()
+
+        elif key in ("_", "-"):
+            self.explorer.decrease_width()
+
+        elif key == "=":
+            self.explorer.extra_width = 0
+
+        # Overview ############################################################
+
         elif key in ("{", "}"):
             if not callable(self.explorer.selected_object.obj):
                 return
@@ -344,8 +353,6 @@ class ObjExploreApp:
             str_out = capture.get()
             pydoc.pager(str_out)
 
-        # Other ################################################################
-
     def draw(self, *args):
         """ Draw the application. the *args argument is due to resize events and are unused """
         print(self.term.home, end="")
